// File autogenerated

// declaration include
#include "accesspointproxy.h"

// Qt includes
#include <qmap.h>
#include <qstring.h>
#include <qvaluelist.h>

// Qt D-Bus includes
#include <dbus/qdbusconnection.h>
#include <dbus/qdbusdata.h>
#include <dbus/qdbusdatalist.h>
#include <dbus/qdbusdatamap.h>
#include <dbus/qdbuserror.h>
#include <dbus/qdbusmessage.h>
#include <dbus/qdbusproxy.h>
#include <dbus/qdbusvariant.h>


namespace DBus
{

AccessPointProxy::AccessPointProxy(const QString& service, const QString& path, QObject* parent, const char* name)
    : QObject(parent, name),
      m_baseProxy(new QDBusProxy())
{
    m_baseProxy->setInterface("org.freedesktop.NetworkManager.AccessPoint");
    m_baseProxy->setPath(path);
    m_baseProxy->setService(service);

    QObject::connect(m_baseProxy, SIGNAL(dbusSignal(const QDBusMessage&)),
                     this,        SLOT(slotHandleDBusSignal(const QDBusMessage&)));
}

AccessPointProxy::~AccessPointProxy()
{
    delete m_baseProxy;
}

void AccessPointProxy::setConnection(const QDBusConnection& connection)
{
    m_baseProxy->setConnection(connection);
}

void AccessPointProxy::setDBusProperty(const QString& name, const QDBusVariant& value, QDBusError& error)
{
    QDBusConnection connection = m_baseProxy->connection();

    QDBusMessage message = QDBusMessage::methodCall(m_baseProxy->service(), m_baseProxy->path(), "org.freedesktop.DBus.Properties", "Set");

    message << QDBusData::fromString(m_baseProxy->interface());
    message << QDBusData::fromString(name);
    message << QDBusData::fromVariant(value);

    connection.sendWithReply(message, &error);
}

QDBusVariant AccessPointProxy::getDBusProperty(const QString& name, QDBusError& error) const
{
    QDBusConnection connection = m_baseProxy->connection();

    QDBusMessage message = QDBusMessage::methodCall(m_baseProxy->service(), m_baseProxy->path(), "org.freedesktop.DBus.Properties", "Get");

    message << QDBusData::fromString(m_baseProxy->interface());
    message << QDBusData::fromString(name);

    QDBusMessage reply = connection.sendWithReply(message, &error);

    if (reply.type() != QDBusMessage::ReplyMessage) return QDBusVariant();
    if (reply.count() != 1) return QDBusVariant();

    bool ok = false;
    QDBusVariant value = reply.front().toVariant(&ok);
    if (!ok) return QDBusVariant();

    return value;
}

Q_UINT32 AccessPointProxy::getFlags(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Flags", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 AccessPointProxy::getWpaFlags(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("WpaFlags", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 AccessPointProxy::getRsnFlags(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("RsnFlags", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

QValueList<Q_UINT8> AccessPointProxy::getSsid(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Ssid", error);

    if (error.isValid()) return QValueList<Q_UINT8>();

    bool ok = false;

    bool subOK = false;

    QValueList<Q_UINT8> result =  variant.value.toList(&ok).toByteList(&subOK);
    if (!subOK) {}
    if (!ok) {}

    return result;
}

Q_UINT32 AccessPointProxy::getFrequency(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Frequency", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

QString AccessPointProxy::getHwAddress(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("HwAddress", error);

    if (error.isValid()) return QString();

    bool ok = false;

    QString result =  variant.value.toString(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 AccessPointProxy::getMode(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Mode", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 AccessPointProxy::getMaxBitrate(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("MaxBitrate", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

Q_UINT8 AccessPointProxy::getStrength(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Strength", error);

    if (error.isValid()) return Q_UINT8();

    bool ok = false;

    Q_UINT8 result =  variant.value.toByte(&ok);
    if (!ok) {}

    return result;
}

void AccessPointProxy::slotHandleDBusSignal(const QDBusMessage& message)
{
    if (message.member() == "PropertiesChanged")
    {
        QMap<QString, QDBusVariant> _properties = message[0].toStringKeyMap().toVariantMap();

        emit PropertiesChanged(_properties);
    }
}

}; // namespace DBus

// End of File

