// File autogenerated

// declaration include
#include "deviceproxy.h"

// Qt includes
#include <qstring.h>

// Qt D-Bus includes
#include <dbus/qdbusconnection.h>
#include <dbus/qdbuserror.h>
#include <dbus/qdbusmessage.h>
#include <dbus/qdbusobjectpath.h>
#include <dbus/qdbusproxy.h>
#include <dbus/qdbusvariant.h>


namespace DBus
{

DeviceProxy::DeviceProxy(const QString& service, const QString& path, QObject* parent, const char* name)
    : QObject(parent, name),
      m_baseProxy(new QDBusProxy())
{
    m_baseProxy->setInterface("org.freedesktop.NetworkManager.Device");
    m_baseProxy->setPath(path);
    m_baseProxy->setService(service);

    QObject::connect(m_baseProxy, SIGNAL(dbusSignal(const QDBusMessage&)),
                     this,        SLOT(slotHandleDBusSignal(const QDBusMessage&)));
}

DeviceProxy::~DeviceProxy()
{
    delete m_baseProxy;
}

void DeviceProxy::setConnection(const QDBusConnection& connection)
{
    m_baseProxy->setConnection(connection);
}

void DeviceProxy::setDBusProperty(const QString& name, const QDBusVariant& value, QDBusError& error)
{
    QDBusConnection connection = m_baseProxy->connection();

    QDBusMessage message = QDBusMessage::methodCall(m_baseProxy->service(), m_baseProxy->path(), "org.freedesktop.DBus.Properties", "Set");

    message << QDBusData::fromString(m_baseProxy->interface());
    message << QDBusData::fromString(name);
    message << QDBusData::fromVariant(value);

    connection.sendWithReply(message, &error);
}

QDBusVariant DeviceProxy::getDBusProperty(const QString& name, QDBusError& error) const
{
    QDBusConnection connection = m_baseProxy->connection();

    QDBusMessage message = QDBusMessage::methodCall(m_baseProxy->service(), m_baseProxy->path(), "org.freedesktop.DBus.Properties", "Get");

    message << QDBusData::fromString(m_baseProxy->interface());
    message << QDBusData::fromString(name);

    QDBusMessage reply = connection.sendWithReply(message, &error);

    if (reply.type() != QDBusMessage::ReplyMessage) return QDBusVariant();
    if (reply.count() != 1) return QDBusVariant();

    bool ok = false;
    QDBusVariant value = reply.front().toVariant(&ok);
    if (!ok) return QDBusVariant();

    return value;
}

QString DeviceProxy::getUdi(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Udi", error);

    if (error.isValid()) return QString();

    bool ok = false;

    QString result =  variant.value.toString(&ok);
    if (!ok) {}

    return result;
}

QString DeviceProxy::getInterface(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Interface", error);

    if (error.isValid()) return QString();

    bool ok = false;

    QString result =  variant.value.toString(&ok);
    if (!ok) {}

    return result;
}

QString DeviceProxy::getDriver(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Driver", error);

    if (error.isValid()) return QString();

    bool ok = false;

    QString result =  variant.value.toString(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 DeviceProxy::getCapabilities(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Capabilities", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

Q_INT32 DeviceProxy::getIp4Address(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Ip4Address", error);

    if (error.isValid()) return Q_INT32();

    bool ok = false;

    Q_INT32 result =  variant.value.toInt32(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 DeviceProxy::getState(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("State", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

QDBusObjectPath DeviceProxy::getIp4Config(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Ip4Config", error);

    if (error.isValid()) return QDBusObjectPath();

    bool ok = false;

    QDBusObjectPath result =  variant.value.toObjectPath(&ok);
    if (!ok) {}

    return result;
}

bool DeviceProxy::getManaged(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("Managed", error);

    if (error.isValid()) return bool();

    bool ok = false;

    bool result =  variant.value.toBool(&ok);
    if (!ok) {}

    return result;
}

Q_UINT32 DeviceProxy::getDeviceType(QDBusError& error) const
{
    QDBusVariant variant = getDBusProperty("DeviceType", error);

    if (error.isValid()) return Q_UINT32();

    bool ok = false;

    Q_UINT32 result =  variant.value.toUInt32(&ok);
    if (!ok) {}

    return result;
}

void DeviceProxy::slotHandleDBusSignal(const QDBusMessage& message)
{
    if (message.member() == "StateChanged")
    {
        Q_UINT32 _state = message[0].toUInt32();

        emit StateChanged(_state);
    }
}

}; // namespace DBus

// End of File

